@@ -31,7 +31,6 @@ def initialized_install_dependencies_plugin(project):
     project.set_property_if_unset("dir_install_logs", "$dir_logs/install_dependencies")
     project.set_property_if_unset("install_dependencies_index_url", None)
     project.set_property_if_unset("install_dependencies_extra_index_url", None)
-    project.set_property_if_unset("install_dependencies_use_mirrors", True)
     project.set_property_if_unset("install_dependencies_upgrade", False)
 
 
@@ -83,7 +82,7 @@ def install_dependency(logger, project, dependency):
     logger.info("Installing dependency '%s'%s", dependency.name, " from %s" % dependency.url if dependency.url else "")
     log_file = project.expand_path("$dir_install_logs", dependency.name)
 
-    pip_command_line = "pip install {0}{1}".format(build_pip_install_options(project), as_pip_argument(dependency))
+    pip_command_line = "pip install {0}'{1}'".format(build_pip_install_options(project), as_pip_argument(dependency))
     exit_code = execute_command(pip_command_line, log_file, shell=True)
     if exit_code != 0:
         if project.get_property("verbose"):
@@ -101,8 +100,6 @@ def build_pip_install_options(project):
         options.append("--index-url " + project.get_property("install_dependencies_index_url"))
         if project.get_property("install_dependencies_extra_index_url"):
             options.append("--extra-index-url " + project.get_property("install_dependencies_extra_index_url"))
-    if project.get_property("install_dependencies_use_mirrors"):
-        options.append("--use-mirrors")
 
     if project.get_property("install_dependencies_upgrade"):
         options.append("--upgrade")
