@@ -26,6 +26,7 @@ except NameError:
 
 DEFAULT_SOURCE_DIRECTORY = 'src/main/python'
 DEFAULT_UNITTEST_DIRECTORY = 'src/unittest/python'
+DEFAULT_SCRIPTS_DIRECTORY = 'src/main/scripts'
 PLUGINS_TO_SUGGEST = ['python.flake8', 'python.coverage', 'python.distutils']
 
 
@@ -42,6 +43,7 @@ def collect_project_information():
     dir_source_main_python = prompt_user('Source directory', DEFAULT_SOURCE_DIRECTORY)
     dir_source_unittest_python = prompt_user(
         'Unittest directory', DEFAULT_UNITTEST_DIRECTORY)
+    dir_source_main_scripts = prompt_user("Scripts directory", DEFAULT_SCRIPTS_DIRECTORY)
 
     plugins = suggest_plugins(PLUGINS_TO_SUGGEST)
     scaffolding.add_plugins(plugins)
@@ -50,6 +52,8 @@ def collect_project_information():
         scaffolding.dir_source_main_python = dir_source_main_python
     if dir_source_unittest_python:
         scaffolding.dir_source_unittest_python = dir_source_unittest_python
+    if dir_source_main_scripts:
+        scaffolding.dir_source_main_scripts = dir_source_main_scripts
 
     return scaffolding
 
@@ -104,6 +108,7 @@ def set_properties(project):
         self.project_name = project_name
         self.dir_source_main_python = DEFAULT_SOURCE_DIRECTORY
         self.dir_source_unittest_python = DEFAULT_UNITTEST_DIRECTORY
+        self.dir_source_main_scripts = DEFAULT_SCRIPTS_DIRECTORY
         self.core_imports = ['use_plugin']
         self.plugins = ['python.core', 'python.unittest', 'python.install_dependencies']
         self.initializer = ''
@@ -128,6 +133,8 @@ def set_properties(project):
             properties_to_set.append(('dir_source_main_python', self.dir_source_main_python))
         if not self.is_default_source_unittest_python:
             properties_to_set.append(('dir_source_unittest_python', self.dir_source_unittest_python))
+        if not self.is_default_source_main_scripts:
+            properties_to_set.append(('dir_source_main_scripts', self.dir_source_main_scripts))
 
         initializer_body = self._build_initializer_body_with_properties(properties_to_set)
 
@@ -141,9 +148,14 @@ def set_properties(project):
     def is_default_source_unittest_python(self):
         return self.dir_source_unittest_python == DEFAULT_UNITTEST_DIRECTORY
 
+    @property
+    def is_default_source_main_scripts(self):
+        return self.dir_source_main_scripts == DEFAULT_SCRIPTS_DIRECTORY
+
     def set_up_project(self):
         for needed_directory in (self.dir_source_main_python,
-                                 self.dir_source_unittest_python):
+                                 self.dir_source_unittest_python,
+                                 self.dir_source_main_scripts):
             if not os.path.exists(needed_directory):
                 os.makedirs(needed_directory)
 
